==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Effacer les statistiques', # MODIF

	// I
	'icone_evolution_visites' => 'Evolucion dei visitas<br />@visites@ visitas',
	'icone_repartition_actuelle' => 'Afichar la reparticion actuala',
	'icone_repartition_visites' => 'Desreparticion dei visitas',
	'icone_statistiques_visites' => 'Estadisticas',
	'info_affichier_visites_articles_plus_visites' => 'Afichar li visitas per lu <b>articles mai visitats despí lo principi :</b>',
	'info_comment_lire_tableau' => 'Coma lièger aqueu tablèu',
	'info_forum_statistiques' => 'Estadisticas dei visitas',
	'info_popularite_2' => 'popularitat dau sit:',
	'info_popularite_3' => 'popularitat: @popularite@; visitas: @visites@',
	'info_popularite_5' => 'popularitat:',
	'info_visites' => 'visitas:',
	'info_visites_plus_populaires' => 'Far paréisser li visitas <b>per articles mai populars</b> e <b>per darriers articles publicats:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Pas gerar li estadisticas', # MODIF

	// O
	'onglet_origine_visites' => 'Origina dei visitas',
	'onglet_repartition_debut' => 'despí lo principi',
	'onglet_repartition_lang' => 'Reparticion per lengas',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Lo reng de l’article,
dins lo classament per popularitat, es indicat dins lo marge; la popularitat de l’article 
(una estimacion dau nombre de visitas quotidiani que recebrà se lo ritme actuau de consultacion si manten) e lo nombre de visitas recebudi
despí lo començament s’afichan dins la bofa
qu’apareisse quora la rateta passa sus lo titre.',
	'texte_signification' => 'Li barras rogi representan li intradas cumuladi (totau dei sosrubricas), li barras verdi lo nombre de visitas per cada rubrica.',
	'titre_evolution_visite' => 'Evolucion dei visitas',
	'titre_liens_entrants' => 'Estacs intrants',
	'titre_page_statistiques' => 'Estatisticas per rubricas',
	'titre_page_statistiques_visites' => 'Estatisticas dei visitas'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=oc_ni
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_statistiques' => 'Effacer les statistiques', # MODIF

	// I
	'icone_evolution_visites' => 'Evolucion dei visitas<br />@visites@ visitas',
	'icone_repartition_actuelle' => 'Afichar la reparticion actuala',
	'icone_repartition_visites' => 'Desreparticion dei visitas',
	'icone_statistiques_visites' => 'Estadisticas',
	'info_affichier_visites_articles_plus_visites' => 'Afichar li visitas per lu <b>articles mai visitats despí lo principi :</b>',
	'info_comment_lire_tableau' => 'Coma lièger aqueu tablèu',
	'info_forum_statistiques' => 'Estadisticas dei visitas',
	'info_popularite_2' => 'popularitat dau sit:',
	'info_popularite_3' => 'popularitat: @popularite@; visitas: @visites@',
	'info_popularite_5' => 'popularitat:',
	'info_visites' => 'visitas:',
	'info_visites_plus_populaires' => 'Far paréisser li visitas <b>per articles mai populars</b> e <b>per darriers articles publicats:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Pas gerar li estadisticas', # MODIF

	// O
	'onglet_origine_visites' => 'Origina dei visitas',
	'onglet_repartition_debut' => 'despí lo principi',
	'onglet_repartition_lang' => 'Reparticion per lengas',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Lo reng de l’article,
dins lo classament per popularitat, es indicat dins lo marge; la popularitat de l’article 
(una estimacion dau nombre de visitas quotidiani que recebrà se lo ritme actuau de consultacion si manten) e lo nombre de visitas recebudi
despí lo començament s’afichan dins la bofa
qu’apareisse quora la rateta passa sus lo titre.',
	'texte_signification' => 'Li barras rogi representan li intradas cumuladi (totau dei sosrubricas), li barras verdi lo nombre de visitas per cada rubrica.',
	'titre_evolution_visite' => 'Evolucion dei visitas',
	'titre_liens_entrants' => 'Estacs intrants',
	'titre_page_statistiques' => 'Estatisticas per rubricas',
	'titre_page_statistiques_visites' => 'Estatisticas dei visitas',
];
